@@ -5,9 +5,9 @@ use strict;
 use warnings;
 use Text::Markup;
 use File::BOM qw(open_bom);
-use Text::Markdown ();
+use Text::Markdown::Discount;
 
-our $VERSION = '0.33';
+our $VERSION = '0.40';
 
 sub import {
     # Replace the regex if passed one.
@@ -17,9 +17,8 @@ sub import {
 sub parser {
     my ($file, $encoding, $opts) = @_;
     my %params = @{ $opts };
-    my $md = Text::Markdown->new(%params);
     open_bom my $fh, $file, ":encoding($encoding)";
-    my $html = $md->markdown(join '', <$fh>);
+    my $html = Text::Markdown::Discount::markdown(join '', <$fh>);
     return unless $html =~ /\S/;
     utf8::encode($html);
     return $html if $params{raw};
@@ -55,7 +54,7 @@ Text::Markup::Markdown - Markdown parser for Text::Markup
 This is the L<Markdown|https://daringfireball.net/projects/markdown/> parser
 for L<Text::Markup>. It reads in the file (relying on a
 L<BOM|https://www.unicode.org/unicode/faq/utf_bom.html#BOM>), hands it off to
-L<Text::Markdown> for parsing, and then returns the generated HTML as an
+L<Text::Markdown::Discount> for parsing, and then returns the generated HTML as an
 encoded UTF-8 string with an C<http-equiv="Content-Type"> element identifying
 the encoding as UTF-8.
 
@@ -84,19 +83,6 @@ Normally this module returns the output wrapped in a minimal HTML document
 skeleton. If you would like the raw output without the skeleton, you can pass
 the C<raw> option to C<parse>.
 
-In addition, Text::Markup::Markdown supports all of the
-L<Text::Markdown options|Text::Markdown/OPTIONS>, including:
-
-=over
-
-=item C<empty_element_suffix>
-
-=item C<tab_width>
-
-=item C<trust_list_start_value>
-
-=back
-
 =head1 See Also
 
 L<National Funk Congress Deadlocked On Get Up/Get Down Issue|https://www.theonion.com/national-funk-congress-deadlocked-on-get-up-get-down-is-1819565355>.
@@ -108,7 +94,7 @@ David E. Wheeler <david@justatheory.com>
 
 =head1 Copyright and License
 
-Copyright (c) 2011-2024 David E. Wheeler. Some Rights Reserved.
+Copyright (c) 2011-2025 David E. Wheeler. Some Rights Reserved.
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
